========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/solum.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

=====
Solum
=====
Application Lifecycle Management


An OpenStack project designed to make cloud services easier to
consume and integrate into your application development process.

Overview
--------
Solum is natively designed for OpenStack clouds and leverages numerous
OpenStack projects, including Keystone, Swift, Glance, Heat, Nova, Trove, and more.
We value vendor neutrality, open design and collaboration, and leveraging existing
solutions where possible. One example is our use of Docker for deployment of
containers. Multiple language run-time environments will be supported with a
modular "language pack" solution so you can easily run applications written
in any language of your choice.

* Free software: Apache 2.0 License. See LICENSE file.
* Documentation: https://docs.openstack.org/solum/latest/

Development-setup with Solum
-----------------------------

See the solum-development-setup_ guide.

.. _solum-development-setup: https://wiki.openstack.org/wiki/Solum/solum-development-setup

Getting started with Solum
--------------------------

See the getting_started_ guide.

.. _getting_started: https://docs.openstack.org/solum/latest/user/index.html

Project Info
-------------

 * Source Code: https://opendev.org/openstack/solum/
 * Wiki: https://wiki.openstack.org/wiki/Solum
 * Launchpad: https://launchpad.net/solum
 * Blueprints: https://blueprints.launchpad.net/solum
 * Bugs: https://bugs.launchpad.net/solum
 * Code Reviews: https://review.opendev.org/#/q/project:openstack/solum
                 https://review.opendev.org/#/q/project:openstack/python-solumclient
 * IRC: #solum at chat.oftc.net
 * Release notes: https://docs.openstack.org/releasenotes/solum/
